@@ -3,7 +3,7 @@ BEGIN {
   $App::Pocoirc::Status::AUTHORITY = 'cpan:HINRIK';
 }
 BEGIN {
-  $App::Pocoirc::Status::VERSION = '0.25';
+  $App::Pocoirc::Status::VERSION = '0.26';
 }
 
 use strict;
@@ -21,7 +21,7 @@ sub new {
 sub PCI_register {
     my ($self, $irc, %args) = @_;
 
-    $self->{status} = $args{status};
+    $self->{status}{$irc} = $args{status};
     $irc->raw_events(1) if $self->{Verbose};
 
     if ($self->{Trace}) {
@@ -67,24 +67,24 @@ sub _normalize {
 sub S_connected {
     my ($self, $irc) = splice @_, 0, 2;
     my $address = ${ $_[0] };
-    $self->{status}->('debug', 'Event S_connected') if $self->{Trace};
-    $self->{status}->('normal', "Connected to server $address");
+    $self->{status}{$irc}->('debug', 'Event S_connected') if $self->{Trace};
+    $self->{status}{$irc}->('normal', "Connected to server $address");
     return PCI_EAT_NONE;
 }
 
 sub S_disconnected {
     my ($self, $irc) = splice @_, 0, 2;
     my $server = ${ $_[0] };
-    $self->{status}->('debug', 'Event S_disconnected') if $self->{Trace};
-    $self->{status}->('normal', "Disconnected from server $server");
+    $self->{status}{$irc}->('debug', 'Event S_disconnected') if $self->{Trace};
+    $self->{status}{$irc}->('normal', "Disconnected from server $server");
     return PCI_EAT_NONE;
 }
 
 sub S_snotice {
     my ($self, $irc) = splice @_, 0, 2;
     my $notice = _normalize(${ $_[0] });
-    $self->{status}->('debug', 'Event S_snotice') if $self->{Trace};
-    $self->{status}->('normal', "Server notice: $notice");
+    $self->{status}{$irc}->('debug', 'Event S_snotice') if $self->{Trace};
+    $self->{status}{$irc}->('normal', "Server notice: $notice");
     return PCI_EAT_NONE;
 }
 
@@ -93,12 +93,12 @@ sub S_notice {
     my $sender = _normalize(${ $_[0] });
     my $notice = _normalize(${ $_[2] });
 
-    $self->{status}->('debug', 'Event S_notice') if $self->{Trace};
+    $self->{status}{$irc}->('debug', 'Event S_notice') if $self->{Trace};
     if (defined $irc->server_name() && $sender ne $irc->server_name()) {
         return PCI_EAT_NONE;
     }
 
-    $self->{status}->('normal', "Server notice: $notice");
+    $self->{status}{$irc}->('normal', "Server notice: $notice");
     return PCI_EAT_NONE;
 }
 
@@ -106,16 +106,16 @@ sub S_001 {
     my ($self, $irc) = splice @_, 0, 2;
     my $server = ${ $_[0] };
     my $nick = $irc->nick_name();
-    $self->{status}->('debug', 'Event S_001') if $self->{Trace};
-    $self->{status}->('normal', "Logged in to server $server with nick $nick");
+    $self->{status}{$irc}->('debug', 'Event S_001') if $self->{Trace};
+    $self->{status}{$irc}->('normal', "Logged in to server $server with nick $nick");
     return PCI_EAT_NONE;
 }
 
 sub S_identified {
     my ($self, $irc) = splice @_, 0, 2;
     my $nick = $irc->nick_name();
-    $self->{status}->('debug', 'Event S_identified') if $self->{Trace};
-    $self->{status}->('normal', "Identified with NickServ as $nick");
+    $self->{status}{$irc}->('debug', 'Event S_identified') if $self->{Trace};
+    $self->{status}{$irc}->('normal', "Identified with NickServ as $nick");
     return PCI_EAT_NONE;
 }
 
@@ -125,9 +125,9 @@ sub S_nick {
     my $newnick = _normalize(${ $_[1] });
     my $oldnick = (split /!/, $user)[0];
 
-    $self->{status}->('debug', 'Event S_nick') if $self->{Trace};
+    $self->{status}{$irc}->('debug', 'Event S_nick') if $self->{Trace};
     return PCI_EAT_NONE if $newnick ne $irc->nick_name();
-    $self->{status}->('normal', "Nickname changed from $oldnick to $newnick");
+    $self->{status}{$irc}->('normal', "Nickname changed from $oldnick to $newnick");
     return PCI_EAT_NONE;
 }
 
@@ -137,9 +137,9 @@ sub S_join {
     my $chan = _normalize(${ $_[1] });
     my $nick = (split /!/, $user)[0];
 
-    $self->{status}->('debug', 'Event S_join') if $self->{Trace};
+    $self->{status}{$irc}->('debug', 'Event S_join') if $self->{Trace};
     return PCI_EAT_NONE if $nick ne $irc->nick_name();
-    $self->{status}->('normal', "Joined channel $chan");
+    $self->{status}{$irc}->('normal', "Joined channel $chan");
     return PCI_EAT_NONE;
 }
 
@@ -150,11 +150,11 @@ sub S_part {
     my $reason = ref $_[2] eq 'SCALAR' ? _normalize(${ $_[2] }) : '';
     my $nick   = (split /!/, $user)[0];
 
-    $self->{status}->('debug', 'Event S_part') if $self->{Trace};
+    $self->{status}{$irc}->('debug', 'Event S_part') if $self->{Trace};
     return PCI_EAT_NONE if $nick ne $irc->nick_name();
     my $msg = "Parted channel $chan";
     $msg .= " ($reason)" if $reason ne '';
-    $self->{status}->('normal', $msg);
+    $self->{status}{$irc}->('normal', $msg);
     return PCI_EAT_NONE;
 }
 
@@ -166,19 +166,19 @@ sub S_kick {
     my $reason = _normalize(${ $_[3] });
     $kicker    = (split /!/, $kicker)[0];
 
-    $self->{status}->('debug', 'Event S_kick') if $self->{Trace};
+    $self->{status}{$irc}->('debug', 'Event S_kick') if $self->{Trace};
     return PCI_EAT_NONE if $victim ne $irc->nick_name();
     my $msg = "Kicked from $chan by $kicker";
     $msg .= " ($reason)" if length $reason;
-    $self->{status}->('normal', $msg);
+    $self->{status}{$irc}->('normal', $msg);
     return PCI_EAT_NONE;
 }
 
 sub S_error {
     my ($self, $irc) = splice @_, 0, 2;
     my $error = _normalize(${ $_[0] });
-    $self->{status}->('debug', 'Event S_error') if $self->{Trace};
-    $self->{status}->('normal', "Error from IRC server: $error");
+    $self->{status}{$irc}->('debug', 'Event S_error') if $self->{Trace};
+    $self->{status}{$irc}->('normal', "Error from IRC server: $error");
     return PCI_EAT_NONE;
 }
 
@@ -188,42 +188,42 @@ sub S_quit {
     my $reason = _normalize(${ $_[1] });
     my $nick   = (split /!/, $user)[0];
 
-    $self->{status}->('debug', 'Event S_quit') if $self->{Trace};
+    $self->{status}{$irc}->('debug', 'Event S_quit') if $self->{Trace};
     return PCI_EAT_NONE if $nick ne $irc->nick_name();
     my $msg = 'Quit from IRC';
     $msg .= " ($reason)" if length $reason;
-    $self->{status}->('normal', $msg);
+    $self->{status}{$irc}->('normal', $msg);
     return PCI_EAT_NONE;
 }
 
 sub S_shutdown {
     my ($self, $irc) = splice @_, 0, 2;
-    $self->{status}->('debug', 'Event S_shutdown') if $self->{Trace};
-    $self->{status}->('normal', 'Shutting down');
+    $self->{status}{$irc}->('debug', 'Event S_shutdown') if $self->{Trace};
+    $self->{status}{$irc}->('normal', 'Shutting down');
     return PCI_EAT_NONE;
 }
 
 sub S_socketerr {
     my ($self, $irc) = splice @_, 0, 2;
     my $reason = _normalize(${ $_[0] });
-    $self->{status}->('debug', 'Event S_socketerr') if $self->{Trace};
-    $self->{status}->('normal', "Failed to connect to server: $reason");
+    $self->{status}{$irc}->('debug', 'Event S_socketerr') if $self->{Trace};
+    $self->{status}{$irc}->('normal', "Failed to connect to server: $reason");
     return PCI_EAT_NONE;
 }
 
 sub S_socks_failed {
     my ($self, $irc) = splice @_, 0, 2;
     my $reason = _normalize(${ $_[0] });
-    $self->{status}->('debug', 'Event S_socks_failed') if $self->{Trace};
-    $self->{status}->('normal', "Failed to connect to SOCKS server: $reason");
+    $self->{status}{$irc}->('debug', 'Event S_socks_failed') if $self->{Trace};
+    $self->{status}{$irc}->('normal', "Failed to connect to SOCKS server: $reason");
     return PCI_EAT_NONE;
 }
 
 sub S_socks_rejected {
     my ($self, $irc) = splice @_, 0, 2;
     my $code = ${ $_[0] };
-    $self->{status}->('debug', 'Event S_socks_rejected') if $self->{Trace};
-    $self->{status}->('normal', "Connection rejected by SOCKS server (code $code)");
+    $self->{status}{$irc}->('debug', 'Event S_socks_rejected') if $self->{Trace};
+    $self->{status}{$irc}->('normal', "Connection rejected by SOCKS server (code $code)");
     return PCI_EAT_NONE;
 }
 
@@ -231,7 +231,7 @@ sub S_raw {
     my ($self, $irc) = splice @_, 0, 2;
     my $raw = _normalize(${ $_[0] });
     return PCI_EAT_NONE if !$self->{Verbose};
-    $self->{status}->('debug', "Raw: $raw");
+    $self->{status}{$irc}->('debug', "Raw: $raw");
     return PCI_EAT_NONE;
 }
 
@@ -239,7 +239,7 @@ sub _default {
     my ($self, $irc, $event) = splice @_, 0, 3;
     return PCI_EAT_NONE if !$self->{Trace};
     return PCI_EAT_NONE if $event =~ /^S_plugin_/;
-    $self->{status}->('debug', "Event $event") if $self->{Trace};
+    $self->{status}{$irc}->('debug', "Event $event") if $self->{Trace};
     return PCI_EAT_NONE;
 }
 
